pub struct ArrayManifoldData {
pub steering_vectors: Vec<Vec<Complex64>>,
pub scan_angles: Vec<f64>,
pub n_elements: usize,
}Expand description
Array manifold: set of steering vectors for a range of angles
Fields
steering_vectors: Vec<Vec<Complex64>>Steering vectors, one per scan angle
scan_angles: Vec<f64>Corresponding scan angles in radians
n_elements: usizeNumber of elements
Implementations
Sourceimpl ArrayManifoldData
impl ArrayManifoldData
Sourcepub fn compute(
array: &dyn ArrayGeometry,
scan_angles_rad: &[f64],
wavelength: f64,
) -> SignalResult<Self>
pub fn compute( array: &dyn ArrayGeometry, scan_angles_rad: &[f64], wavelength: f64, ) -> SignalResult<Self>
Compute the array manifold for a given geometry and scan range
Arguments
array- Array geometryscan_angles_rad- Angles to compute steering vectors forwavelength- Signal wavelength